#!/usr/bin/env RScript
# CLEAN META
# load packages and data
library(readxl)
library(dplyr)
meta <- read_excel("fish_metadata.xlsx")

# Select specific columns
meta <- meta %>%
  select(SampleID, host_scientific_name, common_name, sample_type, Diet, trophic)

# Clean
meta_clean <- meta[meta$sample_type %in% c("midgut", "hindgut"), ]
meta_clean <- meta_clean[meta_clean$Diet != "not applicable", ]
write.csv(meta_clean, file = "cleaned_meta.csv", row.names = FALSE)

#-----------------------------------------------------------------------------------
# SPLIT DIET COLUMN 
library(tidyr)
library(dplyr)
library(readxl)

meta <- read_excel("grouped_cleaned_meta.xlsx")

#into a new row
splitmeta_row <- separate_rows(meta, detail_grouping, sep = "&", convert = FALSE)
write.csv(splitmeta_row, file = "split_grouped_cleaned_meta.csv", row.names = FALSE)

#into a new column
splitmeta_column <- separate(meta, detail_grouping, into = c("diet1", "diet2", "diet3"), sep = "&")
write.csv(splitmeta_column, file = "COLUMN_split_grouped_cleaned_meta.csv", row.names = FALSE)

#-----------------------------------------------------------------------------------
# UPDATE META TO BE YES/NO

meta <- read_excel("grouped_cleaned_meta.xlsx")

meta_dietyesno <- meta %>%
  separate_rows(detail_grouping, sep = "&") %>%
  pivot_wider(names_from = detail_grouping, values_from = detail_grouping, values_fn = length, values_fill = 0) %>%
  mutate(across(starts_with("detail_grouping"), ~ ifelse(. > 0, "yes", "no")))

write.csv(meta_dietyesno, file = "meta_dietyesno.csv", row.names = FALSE)

#-----------------------------------------------------------------------------------
#UPDATE MANIFEST TO MATCH META
meta <- read.csv("cleaned_meta.csv")
manifest <- read.delim("fish_manifest.txt")

sub_manifest <- semi_join(manifest, meta, "sample.id") #make sure column names are both the same
write.csv(sub_manifest, file = "clean_manifest.csv", row.names = FALSE)

#-----------------------------------------------------------------------------------
#CATEGORY INFORMATION

meta <- read.delim("split_grouped_cleaned_meta.csv", sep = ",")
category_counts <- meta %>%
  group_by(detail_grouping) %>%
  summarize(count = n())
write.csv(category_counts, file = "category_counts.csv", row.names = FALSE)
