#!/usr/bin/env RScript

#load packages
library(phyloseq)
library(ape) 
library(tidyverse)
library(vegan)

#load inputs
meta <- read_delim("meta.tsv", delim="\t", col_types = cols(.default = "c"))
samp_df <- as.data.frame(meta[,-1])
rownames(samp_df)<- meta$'sample-ID' 
SAMP <- sample_data(samp_df)

otu <- read_delim("feature-table.txt", delim="\t", skip=1)
otu_mat <- as.matrix(otu[,-1])
rownames(otu_mat) <- otu$`#OTU ID`
OTU <- otu_table(otu_mat, taxa_are_rows = TRUE) 

tax <- read_delim("taxonomy.tsv", delim="\t")
tax_mat <- tax %>% select(-Confidence)%>%
  separate(col=Taxon, sep="; "
           , into = c("Domain","Phylum","Class","Order","Family","Genus","Species")) %>%
  as.matrix() # Saving as a matrix
tax_mat <- tax_mat[,-1]
rownames(tax_mat) <- tax$`Feature ID`
TAX <- tax_table(tax_mat)

phylotree <- read.tree("tree.nwk")

#create phyloseq object 
fish <- phyloseq(OTU, SAMP, TAX, phylotree)
save(fish, file="fish_phyloseq.RData")

#visualize
gg_richness <- plot_richness(fish, x = "gen_grouping", measures = c("Shannon","Chao1")) +
  xlab("Subject ID") +
  geom_boxplot()
gg_richness

ggsave(filename = "plot_richness.png"
       , gg_richness
       , height=4, width=6)

estimate_richness(fish)
